# More Than Inference

An Application Framework of Inference for Distribution


## TASK SUPPORT

| Task            | HTTP | ZeroMQ | gRPC | Crypt |
|:---------------:|:----:|:------:|:----:|:-----:|
| Classification  | ❌    | ❌      | ❌    | ❌     |
| ObjectDetection | ✅    | ✅      | ❌    | ❌     |
| Segmentation    | ❌    | ❌      | ❌    | ❌     |
| Track           | ❌    | ❌      | ❌    | ❌     |
| Text2Text       | ❌    | ❌      | ❌    | ❌     |
| Text2Image      | ✅    | ❌      | ❌    | ❌     |
| Image2Text      | ❌    | ❌      | ❌    | ❌     |
| Image2Image     | ✅    | ❌      | ❌    | ❌     |
| Text2Video      | ❌    | ❌      | ❌    | ❌     |
| Image2Video     | ❌    | ❌      | ❌    | ❌     |
| Text2Speech     | ❌    | ❌      | ❌    | ❌     |
| OCR             | ❌    | ❌      | ❌    | ❌     |
| Flow            | ❌    | ❌      | ❌    | ❌     |
